﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PlayingWithProperties
{
    /// <summary>
    /// Represents a color as red, green, blue, and alpha components.
    /// </summary>
    public class Color
    {
        /// <summary>
        /// Stores the red component of the color.
        /// </summary>
        private byte red;

        /// <summary>
        /// Get or set the red component of the color.
        /// This is an example of a normal, not auto-implemented property.
        /// the private instance variable called 'red' is this property's
        /// backing field.
        /// </summary>
        public byte Red
        {
            get
            {
                return red;
            }
            set
            {
                red = value;
            }
        }

        /// <summary>
        /// Get or set the green component of the color.
        /// </summary>
        public byte Green { get; set; }

        /// <summary>
        /// Get or set the blue component of the color.
        /// </summary>
        public byte Blue { get; set; }

        /// <summary>
        /// An auto-implemented property with different accessibility levels.
        /// You can do the same thing with non auto-implemented properties.
        /// </summary>
        public byte Alpha { get; private set; }

        /// <summary>
        /// Creates a new color with all of the components specified.
        /// </summary>
        public Color(byte red, byte green, byte blue, byte alpha)
        {
            // Here, I'm setting things through the properties. For the
            // explicitly implemented properties (not auto-implemented) I
            // could theoretically go directly to the backing field, but it
            // is usually safer to go through the property instead, even
            // inside of the class.

            Red = red;
            Green = green;
            Blue = blue;
            Alpha = alpha;
        }

        /// <summary>
        /// Creates a new color with only red, green, and blue components
        /// specified. In this case, alpha will be 255, or completely 
        /// opaque.
        /// </summary>
        public Color(byte red, byte green, byte blue)
        {
            Red = red;
            Green = green;
            Blue = blue;
            Alpha = 255;
        }
    }
}
